@@ -8,4 +8,9 @@
 #define MN_FATAL_ERROR(msg)  wxLogFatalError(wxT("File: [%s]    Line: [%d]   Message: [%s]    errno: [%d]"), __TFILE__, __LINE__, msg, errno);
 #define MN_APP_NAME          "MalonNote"
 #define MN_APP_VERSION       MN_APP_NAME " version" PACKAGE_VERSION
+
+
+#define CONF_APP_NAME "MalonNote"
+#define CONF_WIKI_DIR "WikiDir"
+
 #endif // MNDEF_H
