@@ -6,7 +6,7 @@
 
 #include "config.h"
 
-#define MAX_WIKI_TEXT_SIZE 10000
+#define MAX_WIKI_TEXT_SIZE (1048576*5)
 #define MAX_TOKEN          32
 #define MAX_BUF_SIZE       1024
 #define EXT_TAG             ".txt"
@@ -18,7 +18,7 @@
 #define ALLMEMO_TAG         "malon-all"
 #define TYPESEARCH_TAG      "malon-type:"
 
-#define CODE_SET_EUC_JP	    "euc-jp"
+#define CODE_SET_EUC_JP	    "eucJP"
 #ifdef __WXMAC__
 	#define CODE_SET_SYSTEM "CP932"
 #endif
@@ -65,6 +65,7 @@ private:
 	wxString* fileName;
 	wxString* date;
 	wxString* text;
+	bool      isWriteToFile;
 };
 
 /* Search Result List */
